"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AccordionTrigger = void 0;
var _react = _interopRequireWildcard(require("react"));
var _Context = require("./Context");
var _interactions = require("@react-native-aria/interactions");
var _focus = require("@react-native-aria/focus");
var _utils = require("@gluestack-ui/utils");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const AccordionTrigger = StyledAccordionTrigger => /*#__PURE__*/(0, _react.forwardRef)((_ref, ref) => {
  let {
    children,
    isHovered: isHoveredProp,
    isFocused: isFocusedProp,
    isPressed: isPressedProp,
    isFocusVisible: isFocusVisibleProp,
    ...props
  } = _ref;
  const {
    type,
    isCollapsible,
    setOpenItems,
    openItems
  } = (0, _react.useContext)(_Context.AccordionContext);
  const {
    value,
    isDisabled
  } = (0, _react.useContext)(_Context.AccordionItemContext);
  const {
    pressProps,
    isPressed
  } = (0, _interactions.usePress)({
    isDisabled: isDisabled
  });
  const {
    isHovered,
    hoverProps
  } = (0, _interactions.useHover)();
  const {
    isFocusVisible,
    focusProps: focusRingProps
  } = (0, _focus.useFocusRing)();
  const {
    isFocused,
    focusProps
  } = (0, _focus.useFocus)();
  const toggleItem = () => {
    if (isDisabled || !value) {
      return;
    }
    if (type === 'single') {
      if (isCollapsible) {
        setOpenItems(prevOpenItems => {
          const isItemAlreadyOpen = prevOpenItems.includes(value);
          return isItemAlreadyOpen ? prevOpenItems.filter(index => index !== value) : [value];
        });
      } else {
        setOpenItems(prevOpenItems => {
          const isItemAlreadyOpen = prevOpenItems.includes(value);
          return isItemAlreadyOpen ? prevOpenItems : [value];
        });
      }
    } else {
      if (isCollapsible) {
        setOpenItems(prevOpenItems => {
          const isItemAlreadyOpen = prevOpenItems.includes(value);
          return isItemAlreadyOpen ? prevOpenItems.filter(index => index !== value) : [...prevOpenItems, value];
        });
      } else {
        setOpenItems(prevOpenItems => {
          const isItemAlreadyOpen = prevOpenItems.includes(value);
          return isItemAlreadyOpen ? prevOpenItems : [...prevOpenItems, value];
        });
      }
    }
  };
  return /*#__PURE__*/_react.default.createElement(StyledAccordionTrigger, _extends({
    ref: ref
  }, props, {
    "aria-expanded": openItems.includes(value),
    onPress: (0, _utils.composeEventHandlers)(props === null || props === void 0 ? void 0 : props.onPress, toggleItem),
    states: {
      disabled: isDisabled,
      hover: isHoveredProp || isHovered,
      focus: isFocusedProp || isFocused,
      focusVisible: isFocusVisibleProp || isFocusVisible,
      active: isPressedProp || isPressed
    },
    disabled: isDisabled,
    onPressIn: (0, _utils.composeEventHandlers)(props === null || props === void 0 ? void 0 : props.onPressIn, pressProps.onPressIn),
    onPressOut: (0, _utils.composeEventHandlers)(props === null || props === void 0 ? void 0 : props.onPressOut, pressProps.onPressOut)
    // @ts-ignore - web only
    ,
    onHoverIn: (0, _utils.composeEventHandlers)(props === null || props === void 0 ? void 0 : props.onHoverIn, hoverProps.onHoverIn)
    // @ts-ignore - web only
    ,
    onHoverOut: (0, _utils.composeEventHandlers)(props === null || props === void 0 ? void 0 : props.onHoverOut, hoverProps.onHoverOut),
    onFocus: (0, _utils.composeEventHandlers)((0, _utils.composeEventHandlers)(props === null || props === void 0 ? void 0 : props.onFocus, focusProps.onFocus), focusRingProps.onFocus),
    onBlur: (0, _utils.composeEventHandlers)((0, _utils.composeEventHandlers)(props === null || props === void 0 ? void 0 : props.onBlur, focusProps.onBlur), focusRingProps.onBlur),
    onKeyDown: e => {
      if (e.code === 'Space') {
        toggleItem();
      }
    }
  }), typeof children === 'function' ? children({
    hovered: isHovered,
    focused: isFocused,
    pressed: isPressed,
    disabled: isDisabled,
    focusVisible: isFocusVisible,
    isExpanded: openItems.includes(value)
  }) : children);
});
exports.AccordionTrigger = AccordionTrigger;
//# sourceMappingURL=AccordionTrigger.js.map