function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { forwardRef, useContext } from 'react';
import { AccordionContext, AccordionItemContext } from './Context';
import { useHover, usePress } from '@react-native-aria/interactions';
import { useFocusRing, useFocus } from '@react-native-aria/focus';
import { composeEventHandlers } from '@gluestack-ui/utils';
export const AccordionTrigger = StyledAccordionTrigger => /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    children,
    isHovered: isHoveredProp,
    isFocused: isFocusedProp,
    isPressed: isPressedProp,
    isFocusVisible: isFocusVisibleProp,
    ...props
  } = _ref;
  const {
    type,
    isCollapsible,
    setOpenItems,
    openItems
  } = useContext(AccordionContext);
  const {
    value,
    isDisabled
  } = useContext(AccordionItemContext);
  const {
    pressProps,
    isPressed
  } = usePress({
    isDisabled: isDisabled
  });
  const {
    isHovered,
    hoverProps
  } = useHover();
  const {
    isFocusVisible,
    focusProps: focusRingProps
  } = useFocusRing();
  const {
    isFocused,
    focusProps
  } = useFocus();
  const toggleItem = () => {
    if (isDisabled || !value) {
      return;
    }
    if (type === 'single') {
      if (isCollapsible) {
        setOpenItems(prevOpenItems => {
          const isItemAlreadyOpen = prevOpenItems.includes(value);
          return isItemAlreadyOpen ? prevOpenItems.filter(index => index !== value) : [value];
        });
      } else {
        setOpenItems(prevOpenItems => {
          const isItemAlreadyOpen = prevOpenItems.includes(value);
          return isItemAlreadyOpen ? prevOpenItems : [value];
        });
      }
    } else {
      if (isCollapsible) {
        setOpenItems(prevOpenItems => {
          const isItemAlreadyOpen = prevOpenItems.includes(value);
          return isItemAlreadyOpen ? prevOpenItems.filter(index => index !== value) : [...prevOpenItems, value];
        });
      } else {
        setOpenItems(prevOpenItems => {
          const isItemAlreadyOpen = prevOpenItems.includes(value);
          return isItemAlreadyOpen ? prevOpenItems : [...prevOpenItems, value];
        });
      }
    }
  };
  return /*#__PURE__*/React.createElement(StyledAccordionTrigger, _extends({
    ref: ref
  }, props, {
    "aria-expanded": openItems.includes(value),
    onPress: composeEventHandlers(props === null || props === void 0 ? void 0 : props.onPress, toggleItem),
    states: {
      disabled: isDisabled,
      hover: isHoveredProp || isHovered,
      focus: isFocusedProp || isFocused,
      focusVisible: isFocusVisibleProp || isFocusVisible,
      active: isPressedProp || isPressed
    },
    disabled: isDisabled,
    onPressIn: composeEventHandlers(props === null || props === void 0 ? void 0 : props.onPressIn, pressProps.onPressIn),
    onPressOut: composeEventHandlers(props === null || props === void 0 ? void 0 : props.onPressOut, pressProps.onPressOut)
    // @ts-ignore - web only
    ,
    onHoverIn: composeEventHandlers(props === null || props === void 0 ? void 0 : props.onHoverIn, hoverProps.onHoverIn)
    // @ts-ignore - web only
    ,
    onHoverOut: composeEventHandlers(props === null || props === void 0 ? void 0 : props.onHoverOut, hoverProps.onHoverOut),
    onFocus: composeEventHandlers(composeEventHandlers(props === null || props === void 0 ? void 0 : props.onFocus, focusProps.onFocus), focusRingProps.onFocus),
    onBlur: composeEventHandlers(composeEventHandlers(props === null || props === void 0 ? void 0 : props.onBlur, focusProps.onBlur), focusRingProps.onBlur),
    onKeyDown: e => {
      if (e.code === 'Space') {
        toggleItem();
      }
    }
  }), typeof children === 'function' ? children({
    hovered: isHovered,
    focused: isFocused,
    pressed: isPressed,
    disabled: isDisabled,
    focusVisible: isFocusVisible,
    isExpanded: openItems.includes(value)
  }) : children);
});
//# sourceMappingURL=AccordionTrigger.js.map